.. rst-class:: detail

ExecutionLevel
=========================

.. currentmodule:: compas_rrc

.. autoclass:: ExecutionLevel

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~ExecutionLevel.__init__
    
    